==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkCellPicker.java <==
// java wrapper for vtkCellPicker object
//

package vtk;
import vtk.*;

public class vtkCellPicker extends vtkPicker
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Pick_2(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_2(id0,id1,id2,id3); }

  private native void AddLocator_3(vtkAbstractCellLocator id0);
  public void AddLocator(vtkAbstractCellLocator id0)
    { AddLocator_3(id0); }

  private native void RemoveLocator_4(vtkAbstractCellLocator id0);
  public void RemoveLocator(vtkAbstractCellLocator id0)
    { RemoveLocator_4(id0); }

  private native void RemoveAllLocators_5();
  public void RemoveAllLocators()
    { RemoveAllLocators_5(); }

  private native void SetVolumeOpacityIsovalue_6(double id0);
  public void SetVolumeOpacityIsovalue(double id0)
    { SetVolumeOpacityIsovalue_6(id0); }

  private native double GetVolumeOpacityIsovalue_7();
  public double GetVolumeOpacityIsovalue()
    { return GetVolumeOpacityIsovalue_7(); }

  private native void SetUseVolumeGradientOpacity_8(int id0);
  public void SetUseVolumeGradientOpacity(int id0)
    { SetUseVolumeGradientOpacity_8(id0); }

  private native void UseVolumeGradientOpacityOn_9();
  public void UseVolumeGradientOpacityOn()
    { UseVolumeGradientOpacityOn_9(); }

  private native void UseVolumeGradientOpacityOff_10();
  public void UseVolumeGradientOpacityOff()
    { UseVolumeGradientOpacityOff_10(); }

  private native int GetUseVolumeGradientOpacity_11();
  public int GetUseVolumeGradientOpacity()
    { return GetUseVolumeGradientOpacity_11(); }

  private native void SetPickClippingPlanes_12(int id0);
  public void SetPickClippingPlanes(int id0)
    { SetPickClippingPlanes_12(id0); }

  private native void PickClippingPlanesOn_13();
  public void PickClippingPlanesOn()
    { PickClippingPlanesOn_13(); }

  private native void PickClippingPlanesOff_14();
  public void PickClippingPlanesOff()
    { PickClippingPlanesOff_14(); }

  private native int GetPickClippingPlanes_15();
  public int GetPickClippingPlanes()
    { return GetPickClippingPlanes_15(); }

  private native int GetClippingPlaneId_16();
  public int GetClippingPlaneId()
    { return GetClippingPlaneId_16(); }

  private native double[] GetPickNormal_17();
  public double[] GetPickNormal()
    { return GetPickNormal_17(); }

  private native double[] GetMapperNormal_18();
  public double[] GetMapperNormal()
    { return GetMapperNormal_18(); }

  private native int[]  GetPointIJK_19();
  public int[]  GetPointIJK()
    { return GetPointIJK_19(); }

  private native int[]  GetCellIJK_20();
  public int[]  GetCellIJK()
    { return GetCellIJK_20(); }

  private native int GetPointId_21();
  public int GetPointId()
    { return GetPointId_21(); }

  private native int GetCellId_22();
  public int GetCellId()
    { return GetCellId_22(); }

  private native int GetSubId_23();
  public int GetSubId()
    { return GetSubId_23(); }

  private native double[] GetPCoords_24();
  public double[] GetPCoords()
    { return GetPCoords_24(); }

  private native long GetTexture_25();
  public vtkTexture GetTexture() {
    long temp = GetTexture_25();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPickTextureData_26(int id0);
  public void SetPickTextureData(int id0)
    { SetPickTextureData_26(id0); }

  private native void PickTextureDataOn_27();
  public void PickTextureDataOn()
    { PickTextureDataOn_27(); }

  private native void PickTextureDataOff_28();
  public void PickTextureDataOff()
    { PickTextureDataOff_28(); }

  private native int GetPickTextureData_29();
  public int GetPickTextureData()
    { return GetPickTextureData_29(); }

  public vtkCellPicker() { super(); }

  public vtkCellPicker(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-4-armv7h.pkg.tar.xz: vtk/vtkCellPicker.java <==
// java wrapper for vtkCellPicker object
//

package vtk;
import vtk.*;

public class vtkCellPicker extends vtkPicker
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Pick_2(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_2(id0,id1,id2,id3); }

  private native void AddLocator_3(vtkAbstractCellLocator id0);
  public void AddLocator(vtkAbstractCellLocator id0)
    { AddLocator_3(id0); }

  private native void RemoveLocator_4(vtkAbstractCellLocator id0);
  public void RemoveLocator(vtkAbstractCellLocator id0)
    { RemoveLocator_4(id0); }

  private native void RemoveAllLocators_5();
  public void RemoveAllLocators()
    { RemoveAllLocators_5(); }

  private native void SetVolumeOpacityIsovalue_6(double id0);
  public void SetVolumeOpacityIsovalue(double id0)
    { SetVolumeOpacityIsovalue_6(id0); }

  private native double GetVolumeOpacityIsovalue_7();
  public double GetVolumeOpacityIsovalue()
    { return GetVolumeOpacityIsovalue_7(); }

  private native void SetUseVolumeGradientOpacity_8(int id0);
  public void SetUseVolumeGradientOpacity(int id0)
    { SetUseVolumeGradientOpacity_8(id0); }

  private native void UseVolumeGradientOpacityOn_9();
  public void UseVolumeGradientOpacityOn()
    { UseVolumeGradientOpacityOn_9(); }

  private native void UseVolumeGradientOpacityOff_10();
  public void UseVolumeGradientOpacityOff()
    { UseVolumeGradientOpacityOff_10(); }

  private native int GetUseVolumeGradientOpacity_11();
  public int GetUseVolumeGradientOpacity()
    { return GetUseVolumeGradientOpacity_11(); }

  private native void SetPickClippingPlanes_12(int id0);
  public void SetPickClippingPlanes(int id0)
    { SetPickClippingPlanes_12(id0); }

  private native void PickClippingPlanesOn_13();
  public void PickClippingPlanesOn()
    { PickClippingPlanesOn_13(); }

  private native void PickClippingPlanesOff_14();
  public void PickClippingPlanesOff()
    { PickClippingPlanesOff_14(); }

  private native int GetPickClippingPlanes_15();
  public int GetPickClippingPlanes()
    { return GetPickClippingPlanes_15(); }

  private native int GetClippingPlaneId_16();
  public int GetClippingPlaneId()
    { return GetClippingPlaneId_16(); }

  private native double[] GetPickNormal_17();
  public double[] GetPickNormal()
    { return GetPickNormal_17(); }

  private native double[] GetMapperNormal_18();
  public double[] GetMapperNormal()
    { return GetMapperNormal_18(); }

  private native int[]  GetPointIJK_19();
  public int[]  GetPointIJK()
    { return GetPointIJK_19(); }

  private native int[]  GetCellIJK_20();
  public int[]  GetCellIJK()
    { return GetCellIJK_20(); }

  private native int GetPointId_21();
  public int GetPointId()
    { return GetPointId_21(); }

  private native int GetCellId_22();
  public int GetCellId()
    { return GetCellId_22(); }

  private native int GetSubId_23();
  public int GetSubId()
    { return GetSubId_23(); }

  private native double[] GetPCoords_24();
  public double[] GetPCoords()
    { return GetPCoords_24(); }

  private native long GetTexture_25();
  public vtkTexture GetTexture() {
    long temp = GetTexture_25();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPickTextureData_26(int id0);
  public void SetPickTextureData(int id0)
    { SetPickTextureData_26(id0); }

  private native void PickTextureDataOn_27();
  public void PickTextureDataOn()
    { PickTextureDataOn_27(); }

  private native void PickTextureDataOff_28();
  public void PickTextureDataOff()
    { PickTextureDataOff_28(); }

  private native int GetPickTextureData_29();
  public int GetPickTextureData()
    { return GetPickTextureData_29(); }

  public vtkCellPicker() { super(); }

  public vtkCellPicker(long id) { super(id); }
  public native long   VTKInit();

}
